==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-taskbar/taskbar_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="430"/>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="463"/>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;pulpit</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="465"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Wszystkie pulpity</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="473"/>
        <source>Desktop &amp;%1</source>
        <translation>Pulpit &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="480"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na obecny pulpit</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="489"/>
        <source>Ma&amp;ximize</source>
        <translation>Zma&amp;ksymalizuj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="496"/>
        <source>Maximize vertically</source>
        <translation>Zmaksymalizuj pionowo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="501"/>
        <source>Maximize horizontally</source>
        <translation>Zmaksymalizuj poziomo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="507"/>
        <source>&amp;Restore</source>
        <translation>&amp;Odzyskaj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="511"/>
        <source>Mi&amp;nimize</source>
        <translation>Zmi&amp;nimalizuj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="517"/>
        <source>Roll down</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="523"/>
        <source>Roll up</source>
        <translation>Rozwiń</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="531"/>
        <source>&amp;Layer</source>
        <translation>&amp;Warstwa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="533"/>
        <source>Always on &amp;top</source>
        <translation>Zawsze na &amp;wierzchu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="539"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normalnie</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="545"/>
        <source>Always on &amp;bottom</source>
        <translation>Zawsze pod &amp;spodem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="553"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="81"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="82"/>
        <source>Close group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">Ustawienia listy zadań LXQt</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">Zawartość listy zadań</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="26"/>
        <source>Show windows from c&amp;urrent desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all des&amp;ktops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="56"/>
        <source>Window &amp;grouping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="65"/>
        <source>Show popup on mouse hover </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="75"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="94"/>
        <source>Maximum button width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="107"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">Pokazuj okna z obecnego pulpitu</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">Pokazuj okna ze wszystkich pulpitów</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="120"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">Wygląd listy zadań</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="84"/>
        <source>Button style</source>
        <translation>Styl przycisku</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">Maksymalna szerokość</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="46"/>
        <source>Close on middle-click</source>
        <translation>Zamknij środkowym klawiszem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Icon and text</source>
        <translation>Ikona i tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only icon</source>
        <translation>Tylko ikona</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Only text</source>
        <translation>Tylko tekst</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-taskbar/taskbar_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="477"/>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="511"/>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;pulpit</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="513"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Wszystkie pulpity</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="521"/>
        <source>Desktop &amp;%1</source>
        <translation>Pulpit &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="528"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na obecny pulpit</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="537"/>
        <source>Ma&amp;ximize</source>
        <translation>Zma&amp;ksymalizuj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="544"/>
        <source>Maximize vertically</source>
        <translation>Zmaksymalizuj pionowo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="549"/>
        <source>Maximize horizontally</source>
        <translation>Zmaksymalizuj poziomo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="555"/>
        <source>&amp;Restore</source>
        <translation>&amp;Odzyskaj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="559"/>
        <source>Mi&amp;nimize</source>
        <translation>Zmi&amp;nimalizuj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>Roll down</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="571"/>
        <source>Roll up</source>
        <translation>Rozwiń</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="579"/>
        <source>&amp;Layer</source>
        <translation>&amp;Warstwa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="581"/>
        <source>Always on &amp;top</source>
        <translation>Zawsze na &amp;wierzchu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="587"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normalnie</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="593"/>
        <source>Always on &amp;bottom</source>
        <translation>Zawsze pod &amp;spodem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">Ustawienia listy zadań LXQt</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">Zawartość listy zadań</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="34"/>
        <source>Show only windows from desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="46"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="53"/>
        <source>Show only minimized windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="60"/>
        <source>Raise minimized windows on current desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="77"/>
        <source>Window &amp;grouping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Show popup on mouse hover </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="96"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="115"/>
        <source>Maximum button width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="128"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="154"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="141"/>
        <source>Maximum button height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="174"/>
        <source>Use icons by WindowClass, if available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">Pokazuj okna z obecnego pulpitu</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">Pokazuj okna ze wszystkich pulpitów</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="167"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">Wygląd listy zadań</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="105"/>
        <source>Button style</source>
        <translation>Styl przycisku</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">Maksymalna szerokość</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="67"/>
        <source>Close on middle-click</source>
        <translation>Zamknij środkowym klawiszem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>Ikona i tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>Tylko ikona</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>Tylko tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
